@@ -2,7 +2,7 @@ package Minion::Command::minion::job;
 use Mojo::Base 'Mojolicious::Command';
 
 use Mojo::JSON qw(decode_json);
-use Mojo::Util qw(dumper getopt tablify);
+use Mojo::Util qw(getopt tablify);
 
 has description => 'Manage Minion jobs';
 has usage       => sub { shift->extract_usage };
@@ -21,14 +21,16 @@ sub run {
     'f|foreground'  => \my $foreground,
     'H|history'     => \my $history,
     'L|locks'       => \my $locks,
-    'l|limit=i'     => \(my $limit = 100),
+    'l|limit=i'     => \(my $limit             = 100),
     'n|notes=s'     => sub { $options->{notes} = decode_json($_[1]) },
-    'o|offset=i'    => \(my $offset = 0),
+    'o|offset=i'    => \(my $offset            = 0),
     'P|parent=s'    => sub { push @{$options->{parents}}, $_[1] },
     'p|priority=i'  => \$options->{priority},
     'q|queue=s'     => sub { push @{$options->{queues}}, $options->{queue} = $_[1] },
     'R|retry'       => \my $retry,
+    'retry-failed'  => \my $retry_failed,
     'remove'        => \my $remove,
+    'remove-failed' => \my $remove_failed,
     'S|state=s'     => sub { push @{$options->{states}}, $_[1] },
     's|stats'       => \my $stats,
     'T|tasks'       => \my $tasks,
@@ -48,11 +50,15 @@ sub run {
   return $self->_stats if $stats;
 
   # Show history
-  return print dumper $minion->history if $history;
+  return print Minion::_dump($minion->history) if $history;
 
   # List tasks
   return print tablify [map { [$_, $minion->class_for_task($_)] } keys %{$minion->tasks}] if $tasks;
 
+  # Iterate through failed jobs
+  return $minion->jobs({states => ['failed']})->each(sub { $minion->job($_->{id})->remove }) if $remove_failed;
+  return $minion->jobs({states => ['failed']})->each(sub { $minion->job($_->{id})->retry })  if $retry_failed;
+
   # Locks
   return $minion->unlock($unlock)                                            if $unlock;
   return $self->_list_locks($offset, $limit, @args ? {names => \@args} : ()) if $locks;
@@ -75,7 +81,7 @@ sub run {
   return $minion->foreground($id) || die "Job is not ready.\n" if $foreground;
 
   # Job info
-  print dumper Minion::_datetime($job->info);
+  print Minion::_dump(Minion::_datetime($job->info));
 }
 
 sub _list_jobs {
@@ -95,12 +101,12 @@ sub _list_workers {
   print tablify \@workers;
 }
 
-sub _stats { print dumper shift->app->minion->stats }
+sub _stats { print Minion::_dump(shift->app->minion->stats) }
 
 sub _worker {
   my $worker = shift->app->minion->backend->list_workers(0, 1, {ids => [shift]})->{workers}[0];
   die "Worker does not exist.\n" unless $worker;
-  print dumper Minion::_datetime($worker);
+  print Minion::_dump(Minion::_datetime($worker));
 }
 
 1;
@@ -122,12 +128,13 @@ Minion::Command::minion::job - Minion job command
     ./myapp.pl minion job -s
     ./myapp.pl minion job -f 10023
     ./myapp.pl minion job -q important -t foo -t bar -S inactive
-    ./myapp.pl minion job -Q 'host:localhost' -S inactive
+    ./myapp.pl minion job -q 'host:localhost' -S inactive
     ./myapp.pl minion job -e foo -a '[23, "bar"]'
     ./myapp.pl minion job -e foo -x 1 -P 10023 -P 10024 -p 5 -q important
     ./myapp.pl minion job -e 'foo' -n '{"test":123}'
     ./myapp.pl minion job -R -d 10 -E 300 10023
     ./myapp.pl minion job --remove 10023
+    ./myapp.pl minion job --retry-failed
     ./myapp.pl minion job -n '["test"]'
     ./myapp.pl minion job -L
     ./myapp.pl minion job -L some_lock some_other_lock
@@ -168,7 +175,9 @@ Minion::Command::minion::job - Minion job command
     -q, --queue <name>          Queue to put new job in, defaults to "default",
                                 or list only jobs in these queues
     -R, --retry                 Retry job
+        --retry-failed          Retry all failed jobs at once
         --remove                Remove job
+        --remove-failed         Remove all failed jobs at once
     -S, --state <name>          List only jobs in these states
     -s, --stats                 Show queue statistics
     -T, --tasks                 List available tasks
@@ -215,6 +224,6 @@ Run this command.
 
 =head1 SEE ALSO
 
-L<Minion>, L<https://minion.pm>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
+L<Minion>, L<Minion::Guide>, L<https://minion.pm>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
